#
# spec file for package neverball
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           neverball
Version:        1.6.0
Release:        lp152.3.7
Summary:        Deftly Guide a Rolling Ball through Many Slick 3D Levels
License:        GPL-2.0+
Group:          Amusements/Games/3D/Other
Url:            http://neverball.org
Source:         http://%{name}.org/%{name}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM https://github.com/Neverball/neverball/pull/142
Patch1:         appdata.patch
%define	        name2 neverputt
%define	        name3 mapc
BuildRequires:  dejavu-fonts
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libSDL2-devel
BuildRequires:  libSDL2_ttf-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng16-compat-devel
BuildRequires:  libpng16-devel
BuildRequires:  libvorbis-devel
BuildRequires:  physfs-devel
BuildRequires:  update-desktop-files
Requires:       opengl-games-utils

%description
Tilt the floor to roll a ball through an obstacle course within the
given time. If the ball falls or time expires, a ball is lost.

Collect 100 coins to save your progress and earn an extra ball.
Red coins are worth 5. Blue coins are worth 10.

In the grand tradition of Marble Madness and Super Monkey Ball,
Neverball has you guide a rolling ball through dangerous territory.
Balance on narrow bridges, navigate mazes, ride moving platforms,
and dodge pushers and shovers to get to the goal.
Race against the clock to collect coins to earn extra balls.

%package %{name2}
Summary:        3D mini golf game
Group:          Amusements/Games/3D/Other
Requires:       %{name}

%description %{name2}
A hot-seat multiplayer miniature golf game, built on the physics
and graphics engine of Neverball.

Based on the physics and graphics of Neverball, Neverputt is a hot-seat
multi-player miniature golf game for 1 to 4 players. The available
courses take advantage of all the elements that challenge Neverball
players, including moving platforms and barriers, teleporters, ramps,
and drop-offs. A simple putting interface and golf scoring system
have been added.

%package %{name3}
Summary:        Mapc is a program designed to compile the levels
Group:          Development/Tools/Other
BuildRequires:  libSDL2_net-devel
Requires:       %{name}

%description %{name3}
Mapc is a program designed to compile the levels made with Radiant
to make them usable in Neverball and Neverputt.
All instructions are based upon using command lines.

The output will be saved to Imap.sol.

http://wiki.nevercorner.net/doku.php/mapc

https://icculus.org/neverball/mapping/

%package -n %{name}-doc
Summary:        Documentation for the %{name}
Group:          Documentation
BuildArch:      noarch

%description -n %{name}-doc
Tilt the floor to roll a ball through an obstacle course within the
given time. If the ball falls or time expires, a ball is lost.

Collect 100 coins to save your progress and earn an extra ball.
Red coins are worth 5. Blue coins are worth 10.

In the grand tradition of Marble Madness and Super Monkey Ball,
Neverball has you guide a rolling ball through dangerous territory.
Balance on narrow bridges, navigate mazes, ride moving platforms,
and dodge pushers and shovers to get to the goal.
Race against the clock to collect coins to earn extra balls.

Documentation for the %{name}.

%prep
%setup -q
%patch1 -p1

# Add missing libraries
sed -i -e 's|-lphysfs|-lphysfs -lm|' \
       -e 's|$(OGL_LIBS)|$(OGL_LIBS) -lX11|' Makefile

# Change executebles for OpenGL Wrapper
sed -i 's|Exec=%{name}|Exec=%{name}-wrapper|' dist/%{name}.desktop.in
sed -i 's|Exec=%{name2}|Exec=%{name2}-wrapper|' dist/%{name2}.desktop.in

%build
make %{?_smp_mflags} CC="gcc %{optflags} -fomit-frame-pointer"  \
        DATADIR=%{_datadir}/%{name} LOCALEDIR=%{_datadir}/locale \
        ENABLE_NLS=1 ENABLE_RADIANT_CONSOLE=1

%install
# install executables and mans
for f in %{name} %{name2} %{name3} ; do
    install -Dm 0755 $f %{buildroot}%{_bindir}/$f
done
for f in %{name} %{name2} ; do
    install -Dm 0644 dist/$f.6 %{buildroot}%{_mandir}/man6/$f.6
done
install -Dm 0644 dist/%{name3}.1 %{buildroot}%{_mandir}/man1/%{name3}.1

# Adjust permissions
find data -name '*.sol' -exec chmod 644 '{}' \;

mkdir -p %{buildroot}%{_datadir}/%{name}
cp -r data/* %{buildroot}%{_datadir}/%{name}/

# Symlink executables
for f in %{name} %{name2} %{name3} ; do
    ln -s %{_bindir}/$f %{buildroot}%{_datadir}/%{name}/$f
done

# Use system fonts instead of bundling our own
rm -f %{buildroot}%{_datadir}/%{name}/ttf/DejaVuSans-Bold.ttf
ln -s %{_datadir}/fonts/truetype/DejaVuSans-Bold.ttf %{buildroot}%{_datadir}/%{name}/ttf/DejaVuSans-Bold.ttf

# install icons
for i in 24 32 48 64 128 256 512 ; do
    install -Dm 0644 dist/%{name}_${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
    install -Dm 0644 dist/%{name2}_${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name2}.png
done
mkdir -p %{buildroot}%{_datadir}/pixmaps
for f in %{name} %{name2} ; do
    ln -s %{_datadir}/%{name}/icon/$f.png %{buildroot}%{_datadir}/pixmaps/$f.png
done

# install desktop file
install -Dm 0644 dist/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 0644 dist/%{name2}.desktop %{buildroot}%{_datadir}/applications/%{name2}.desktop

# install software gallery metadata
install -Dm 0644 dist/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

cp -r locale %{buildroot}%{_datadir}/

# symlink OpenGL Wrapper
ln -s opengl-game-wrapper.sh %{buildroot}%{_bindir}/%{name}-wrapper
ln -s opengl-game-wrapper.sh %{buildroot}%{_bindir}/%{name2}-wrapper

%find_lang %name

%suse_update_desktop_file %{name}
%suse_update_desktop_file %{name2}

%fdupes -s %{buildroot}%{_prefix}

%files -f %name.lang
%defattr(-,root,root,-)
%{_bindir}/%{name}
%{_bindir}/%{name}-wrapper
%{_mandir}/man6/%{name}.6%{ext_man}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/
%{_datadir}/pixmaps/*
%{_datadir}/%{name}

%files %{name2}
%defattr(-,root,root,-)
%{_bindir}/%{name2}
%{_bindir}/%{name2}-wrapper
%{_mandir}/man6/%{name2}.6%{ext_man}
%{_datadir}/applications/%{name2}.desktop

%files %{name3}
%defattr(-,root,root,-)
%{_bindir}/%{name3}
%{_mandir}/man1/%{name3}.1%{ext_man}

%files -n %{name}-doc
%defattr(-,root,root,-)
%doc LICENSE.md README.md doc/*.{txt,md}

%changelog
* Sun Feb 19 2017 mailaender@opensuse.org
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Mon Oct  6 2014 nemysis@gmx.ch
- Update to 1.6.0, announce message is here:
  http://neverball.org/release.php
- Change Source to use Web URL
- Remove Desktop entry files, use supplied files
- Add name3 for mapc
- Add BuildRequires for dejavu-fonts, desktop-file-utils,
  hicolor-icon-theme, libSDL2-devel, libSDL2_ttf-devel,
  libpng16-compat-devel, libpng16-devel, libSDL2_net-devel (mapc)
- Remove BuildRequires for libSDL-devel, libSDL_ttf-devel,
  libpng-devel, xorg-x11-libX11-devel
- Add Requires for opengl-games-utils, change executables
  for OpenGL Wrapper and symlink
- Remove obsolete patch neverball-libpng16.patch, changed
  by upstream
- Use sed instead of simple patch neverball-add-needed.patch
- Change description
- Split out neverball, neverputt, mapc and doc into subpackages
- Add to make ENABLE_RADIANT_CONSOLE=1 for mapc
- Simplify installation handling
- Symlink executables, needed for mapc
- Replace bundled font with a symlink to an identical system font
- Add icons
* Fri Feb 15 2013 pgajdos@suse.com
- build also against libpng16
  * libpng16.patch
* Tue Jul 31 2012 dimstar@opensuse.org
- Correctly reference, install and package the language files
  (bnc#699124).
* Fri Mar 23 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant spec sections
- No reason to have files owned by "games"; give them to root
* Wed Sep  7 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed
* Sun Mar 14 2010 dimstar@opensuse.org
- Fix permission of the data files.
* Fri Mar 12 2010 dimstar@opensuse.org
- update to 1.5.4:
  + Loads of changes since version 1.4.0 - please see CHANGES.
- Drop neverball-1.4.0-subscript-out-of-range.patch,
  neverball-1.3.7-config.diff,  neverball-1.4.0-data.diff and
  neverball-game-data.patch.
- Use fdupes to save disk space
- Clean up BuildRequires: Mesa-devel, SDL_image-devel and
  SDL_mixer-devel are dropped, SDL-*-devel replaced with
  libSDL-*-devel. New requirements fdupes, libvorbis-, libpng- and
  libjpeg-devel added.
* Tue Jul 10 2007 gekker@suse.de
- Fix build
* Fri Feb  9 2007 ro@suse.de
- fix build as non-root
* Mon Nov  6 2006 gekker@suse.de
- Remove executable permission from files in %%{datadir}
* Wed Jul 19 2006 gekker@suse.de
- Fix array subscript out of range warning in mapc.c (#185608)
* Fri Mar 10 2006 bk@suse.de
- re-enabled screen resolution 1280x800
- update BuildRequires: Mesa-devel w/o xorg-x11 and freetype-devel
* Fri Jan 27 2006 nadvornik@suse.cz
- fixed BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug 29 2005 gekker@suse.de
- Fix camera configuration as requested by author (64291)
- Install icons for neverball, neverputt (113653, 113654)
* Mon Sep 20 2004 bk@suse.de
- add binary of neverputt (game data is shared with neverball)
* Thu Sep 16 2004 sndirsch@suse.de
- updated to release 1.4.0; changes since 1.3.7
  New in 1.4.0:
  * Fixed font renderer to never exceed maximum texture size.
  New in 1.3.11:
  * Fixed broken Unix build.
  * Added OSX SDL mouse invert workaround.
  * A few texture tweaks.
  * Fixed broken Ball HUD.
  New in 1.3.10:
  * Tweaks to pars.
  * Added wireframe view to Putt.
  * Fixed view toward hole when the hole is directly above or below the ball.
  New in 1.3.9:
  * Made a few minor fixes to paxed's holes.
  * Added score and par to HUD.
  * Show score card only after a hole is finished.
  * Added timeouts to all in-game states except Next Player.
  * Fixed texture ID leak in conf state.
  New in 1.3.8:
  * Modified joystick traversal of GUIs to wrap top/bottom and left/right.
  * Converted Putt to use Ball's GUI API.
  * Merged Putt's and Ball's audio managers into shared.
  * Added "Paused" screen to Putt.
  * Generalized Putt's scoring to allow courses of length other than 18.
  * Enabled switches in Putt.
  * Added paxed's Putt courses.
  * Changed a few textures on paxed's courses.
  * Capped per-hole scores at 12.
  * Modified several Putt backgrounds.
  * Applied a change to Mehdi 25.
  * Added poser mode to Putt.
  * "Fixed" mouse jump on pointer grab.  SDL is unpredictable here.
  * By popular demand, set initial ball view toward hole.
* Wed Aug 25 2004 bk@suse.de
- updated to release 1.3.7 with default camera setting of 1.2.6
- make some of the levels of the easy series more playable
* Fri Feb  6 2004 sndirsch@suse.de
- updated to release 1.1.0
* Sat Aug 30 2003 sndirsch@suse.de
- fixed game category
* Tue Aug 12 2003 sndirsch@suse.de
- added desktop file
* Wed Aug  6 2003 bk@suse.de
- neverball - deftly guide a ball through many slick 3D levels!
